summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/core/core.py11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/core/core.py b/src/core/core.py
index 4269c409..1fe00d2d 100644
--- a/src/core/core.py
+++ b/src/core/core.py
@@ -388,12 +388,19 @@ class Core(object):
def exit_from_signal(self, *args, **kwargs):
"""
Quit when receiving SIGHUP or SIGTERM
do not save the config because it is not a normal exit
(and only roster UI things are not yet saved)
"""
- log.debug("Either SIGHUP or SIGTERM received. Exiting…")
+ sig = args[0]
+ signals = {
+ 1: 'SIGHUP',
+ 13: 'SIGPIPE',
+ 15: 'SIGTERM',
+ }
+
+ log.error("%s received. Exiting…", signals[sig])
if config.get('enable_user_mood', True):
self.xmpp.plugin['xep_0107'].stop(block=False)
if config.get('enable_user_activity', True):
@@ -388,12 +388,19 @@ class Core(object):
def exit_from_signal(self, *args, **kwargs):
"""
- Quit when receiving SIGHUP or SIGTERM
+ Quit when receiving SIGHUP or SIGTERM or SIGPIPE
do not save the config because it is not a normal exit
(and only roster UI things are not yet saved)